
import numpy as np
import h5py
try:
    import yt
    has_yt = True
except:
    has_yt = False
    print("Proceeding without yt.")

frames= [10] #[10,30,60]

field_units = {'Bx':'code_magnetic','By':'code_magnetic','Bz':'code_magnetic',\
               'velocity_x':'code_velocity','velocity_y':'code_velocity','velocity_z':'code_velocity',\
               'density':'code_density'}
unit_conversions = {} #to be read from the files disk
if 1:
    directory = '/scratch1/dcollins/Paper08/B02/512/RootGrids'
    setname_base = 'C12_Beta0.2_256'
    data_shape =np.array([256,256,256])
if 0:
    directory = '/scratch1/dcollins/Paper08/B2/512/RootGrids'
    setname_base = 'C12_Beta2_256'
    data_shape =np.array([256,256,256])
if 0:
    directory = '/scratch1/dcollins/Paper08/B20/512/RootGrids'
    setname_base = 'C12_Beta20_256'
    data_shape =np.array([256,256,256])

for frame in frames:
    set_name = "%s/%s_%04d.h5"%(directory,setname_base,frame)
    fptr = h5py.File(set_name,"r")
    data={}
    try:

        print("reading data for %s"%set_name)
        for field in field_units:
            data[field]=(fptr[field][:] ,field_units[field])
            these_units = fptr[field+"_units"].value.split(" ")
            unit_conversions[field]=(float(these_units[0]),these_units[1])
        these_units = fptr['length_units'].value.split(" ")
        unit_conversions['length']=(float(these_units[0]),these_units[1])
        if has_yt:
            bbox = np.array([[0.,1.],[0.,1.],[0.,1.]])
            ds = yt.load_uniform_grid(data,data_shape, bbox=bbox,periodicity=(True,True,True),\
                                      length_unit=unit_conversions['length'],\
                                      velocity_unit=unit_conversions['velocity_x'],\
                                      magnetic_unit=unit_conversions['Bx'],\
                                      mass_unit=unit_conversions['density'][0]*unit_conversions['length'][0]**3)
    except:
        raise
    finally:
        fptr.close()
    if has_yt:
        print("Computing plasma beta:")
        ad=ds.all_data()
        ad.get_data()  
        bx_mean_yt = np.mean(ad['Bx']).in_units('code_magnetic')
        by_mean_yt = np.mean(ad['By']).in_units('code_magnetic')
        bz_mean_yt = np.mean(ad['Bz']).in_units('code_magnetic')
        density = np.mean(ad['density'])
        cs = yt.YTArray(unit_conversions['velocity_x'][0],'cm/s')
        beta = 8*np.pi*cs**2*density/(bx_mean_yt.in_units('gauss'))**2
        print(beta)
        print(ad['density'])
